
KallistoIdx
===========

A local file



Quickstart
-----------

.. code-block:: python

   from janis_bioinformatics.tools.kallisto.data_types import KallistoIdx

   w = WorkflowBuilder("my_workflow")

   w.input("input_kallistoidx", KallistoIdx(optional=False))
   
   # ...other workflow steps

*This page was automatically generated on 2020-12-22*.
